import copy
from typing import List, TYPE_CHECKING

from PyQt5.QtCore import Qt, QEvent, QObject, QModelIndex, pyqtSignal
from PyQt5.QtWidgets import QListView

from astra_installer.settings.component import Component
from astra_installer.settings.components import ComponentsSetting
from astra_installer.settings.manager import SettingsManager
from astra_installer_qt.component_model import ComponentListModel
from astra_installer_qt.component_proxy_model import ComponentProxyModel

if TYPE_CHECKING:
    from gettext import gettext as _


class ComponentsManager(QObject):
    componentsReady = pyqtSignal()

    def __init__(self, listview: QListView, backend: ComponentsSetting) -> None:
        super(ComponentsManager, self).__init__()
        self.model = ComponentListModel()
        self.proxy = ComponentProxyModel()
        self.backend = backend
        self.listview = listview
        self.setup()

    def setup(self) -> None:
        self.setup_components()
        self.proxy.setSourceModel(self.model)
        self.listview.setModel(self.proxy)
        self.listview.clicked.connect(self.check_index)
        self.listview.installEventFilter(self)
        self.indicate_loading()

    def check_index(self, index: QModelIndex) -> None:
        self.model.check_index(self.proxy.mapToSource(index))

    def setup_components(self) -> None:
        self.model.components = copy.deepcopy(self.backend.components)

    def setup_backend(self) -> None:
        self.backend.components = copy.deepcopy(self.model.components)

    def indicate_loading(self) -> None:
        # TODO: Дикие графические артефакты
        #     self.listview.setEnabled(False)
        # else:
        #     self.listview.setEnabled(True)
        if SettingsManager.systeminfo.oem:
            pass
            # if self.backend.is_components_loaded:
            #     self.listview.setEnabled(True)
            # else:
            #     self.listview.setEnabled(False)

    def setup_components_and_update_label(self):
        self.setup_components()
        self.indicate_loading()
        self.componentsReady.emit()

    def checked_components_string(self, names: List[str], sep: str = ', ') -> str:
        if len(names) > 0:
            return sep.join(names)
        else:
            return self.tr('None')

    def update_components(self, updated_list: List[Component]) -> None:
        updated = {component.ident: component for component in updated_list}
        components = copy.deepcopy(self.model.components)
        for component in components:
            if component.ident in updated:
                component.enabled = updated[component.ident].enabled
                component.selected = updated[component.ident].selected
        self.model.components = components

    # noinspection PyPep8Naming
    def eventFilter(self, qobject: QObject, event: QEvent) -> bool:
        if event.type() == QEvent.KeyPress and event.key() == Qt.Key_Space:
            current = self.listview.currentIndex()
            if current.isValid():
                self.check_index(current)
            return True
        else:
            return False

    def retranslate(self) -> None:
        self.setup_components()
        # self.indicate_loading()
