from datetime import date, time
from typing import TYPE_CHECKING

from PyQt5.QtCore import QObject, QCoreApplication
from PyQt5.QtWidgets import QPushButton, QMainWindow

from astra_installer.settings.manager import SettingsManager
from astra_installer_qt.date_time.ui.date_time_dialog import DateTimeDialog
from astra_installer_qt.timezone_manager import TimeZoneManager

translate = QCoreApplication.translate

if TYPE_CHECKING:
    from gettext import gettext as _


class DateTimeManager(QObject):
    def __init__(self, main_window: QMainWindow,
                 settings_button: QPushButton,
                 timezone: TimeZoneManager) -> None:
        super().__init__()
        self.__settings_button = settings_button
        self.__timezone = timezone
        self.__settings_dialog = DateTimeDialog(parent=main_window)
        self.__setup()

    def retranslate(self, locale: str) -> None:
        self.__settings_dialog.retranslate(locale)

    def __setup(self) -> None:
        self.__settings_button.clicked.connect(self.__settings_button_clicked)
        self.__settings_dialog.settings_changed.connect(self.__settings_changed)

    def __settings_button_clicked(self) -> None:
        self.__settings_dialog.setup_datetime()
        self.__settings_dialog.show()

    def __settings_changed(self, date: date, time: time) -> None:
        SettingsManager.datetime.set_datetime(date, time)
        self.__timezone.refresh_timezones_text()
