from datetime import date, time
from typing import Optional, TYPE_CHECKING

from PyQt5 import uic
from PyQt5.QtCore import QCoreApplication, QLocale, pyqtSignal
from PyQt5.QtGui import QCloseEvent
from PyQt5.QtWidgets import QWidget, QDialog, QPushButton, QDateTimeEdit

from astra_installer.settings.manager import SettingsManager
from astra_installer_qt.utils import Utils as QtUtils

if TYPE_CHECKING:
    from gettext import gettext as _

translate = QCoreApplication.translate

dialog_ui = QtUtils.file_path('date_time', 'ui', 'date_time_dialog.ui')
UiFormClass, UiFormBase = uic.loadUiType(dialog_ui)  # type: QDialog, QDialog


class DateTimeDialog(UiFormClass, UiFormBase):
    settings_changed = pyqtSignal(date, time)

    def __init__(self, parent: QWidget = None) -> None:
        super().__init__(parent=parent)
        self._apply_push_button = None # type: Optional[QPushButton]
        self._cancel_push_button = None # type: Optional[QPushButton]
        self._date_time_edit = None # type: Optional[QDateTimeEdit]
        self.setupUi(self)
        self.__setup()

    def __setup(self) -> None:
        self.setModal(True)
        self.adjustSize()
        self._apply_push_button.clicked.connect(self.accept)
        self._cancel_push_button.clicked.connect(self.reject)
        self.setup_datetime()

    def setup_datetime(self) -> None:
        self._date_time_edit.setDateTime(SettingsManager.datetime.current_datetime())

    def show(self) -> None:
        active_window = QCoreApplication.instance().activeWindow()
        self.setVisible(True)
        self.exec()
        if active_window:
            active_window.activateWindow()

    def retranslate(self, locale: str) -> None:
        self.retranslateUi(self)
        self._date_time_edit.calendarWidget().setLocale(QLocale(locale))

    def accept(self) -> None:
        self.settings_changed.emit(self._date_time_edit.date().toPyDate(),
                                    self._date_time_edit.time().toPyTime())
        return super().accept()

    def reject(self) -> None:
        return super().reject()

    def closeEvent(self, event: QCloseEvent) -> None:
        event.ignore()
        self.reject()
