import os

from PyQt5 import uic
from PyQt5.QtCore import QEvent, QUrl
from PyQt5.QtGui import QShowEvent
from PyQt5.QtWidgets import QDialog

from astra_installer_qt.utils import Utils

dialog_ui = Utils.file_path('ui', 'help_dialog.ui')
UiFormClass, UiFormBase = uic.loadUiType(dialog_ui)  # type: QDialog, QDialog


class HelpDialog(UiFormClass, UiFormBase):
    def __init__(self, help_directory_path: str) -> None:
        super().__init__()
        self.setupUi(self)
        self.help_directory_path = help_directory_path
        self.pushButtonClose.clicked.connect(self.accept)

    def setup(self, locale: str) -> None:
        filename = 'help_{locale}.html'.format(locale=locale)
        path = os.path.join(self.help_directory_path, filename)
        self.helpTextBrowser.setSource(QUrl('file:///{path}'.format(path=path)))

    # noinspection PyPep8Naming
    def changeEvent(self, event: QEvent) -> None:
        if event.type() == QEvent.LanguageChange:
            self.retranslateUi(self)

    # noinspection PyPep8Naming
    def showEvent(self, event: QShowEvent) -> None:
        super().showEvent(event)

        if not Utils.is_wm_present():
            self.setGeometry(self.x(), 115, self.width(), max(self.height(), 400))

    def retranslate(self, locale: str) -> None:
        self.setup(locale)
