from typing import TYPE_CHECKING

from PyQt5.QtCore import QObject, pyqtSignal
from PyQt5.QtWidgets import QLineEdit

from astra_installer.settings.manager import SettingsManager

if TYPE_CHECKING:
    from gettext import gettext as _


class HostnameManager(QObject):
    error = pyqtSignal(str, str)  # id, text
    noerror = pyqtSignal(str)  # id

    def __init__(self, lineedit: QLineEdit) -> None:
        super(HostnameManager, self).__init__()
        self.lineedit = lineedit
        self.backend = SettingsManager.hostname
        self.invalid_hostname = 'hostname'
        self.error_style = "background: #FFFFFF;" \
                           "border: 1px solid #FF0000;" \
                           "border-radius: 2px;" \
                           "border-radius: 2px;"
        self.setup()

    def setup(self) -> None:
        self.lineedit.textChanged.connect(self.on_text_changed)

    def read_settings(self) -> None:
        self.lineedit.setPlaceholderText(self.backend.hostname)
        self.lineedit.setText(self.backend.hostname)
        self.on_text_changed()  # TODO: убрать принудительную валидацию

    def setup_backend(self) -> None:
        self.backend.hostname = self.lineedit.text()

    def on_text_changed(self) -> None:
        valid, error = self.backend.is_valid_hostname(self.lineedit.text())
        if valid:
            self.lineedit.setStyleSheet('')
            self.noerror.emit(self.invalid_hostname)
        else:
            self.lineedit.setStyleSheet(self.error_style)
            self.error.emit(self.invalid_hostname, _(error))
