from PyQt5.QtCore import QObject, pyqtSignal, QTranslator, QLocale, QLibraryInfo
from PyQt5.QtWidgets import QComboBox, QApplication

from astra_installer.settings.manager import SettingsManager
from astra_installer.translator import Translator
from astra_installer_qt.utils import Utils


class InstallerLocaleManager(QObject):
    locale_changed = pyqtSignal(str)

    def __init__(self, combobox: QComboBox) -> None:
        super(InstallerLocaleManager, self).__init__()
        self.combobox = combobox
        self.backend = SettingsManager.installer_locale
        self.system_translator = QTranslator(QApplication.instance())
        self.app_translator = QTranslator(QApplication.instance())
        self.setup()

    def setup(self) -> None:
        QApplication.instance().installTranslator(self.system_translator)
        QApplication.instance().installTranslator(self.app_translator)
        self.combobox.activated.connect(self.change_installer_locale)
        self.add_locales()

    def add_locales(self) -> None:
        self.combobox.clear()
        selected_index = 0
        for index, locale in enumerate(self.backend.locales):
            text = Translator.locale_name(locale, self.backend.selected)
            if locale == self.backend.selected:
                selected_index = index
            else:
                text += ' - ' + Translator.locale_name(locale, locale)
            self.combobox.addItem(text, locale)
        self.combobox.setCurrentIndex(selected_index)

    def change_installer_locale(self) -> None:
        locale = self.combobox.currentData()
        self.backend.change_locale(locale)
        self.system_translator.load('qt_' + locale, QLibraryInfo.location(QLibraryInfo.TranslationsPath))
        self.app_translator.load(QLocale(locale), '', '', Utils.file_path('translations'), '.qm')
        self.add_locales()
        self.locale_changed.emit(locale)
