from PyQt5.QtCore import QObject, QTimer
from PyQt5.QtWidgets import QPushButton
from xkbgroup import XKeyboard


class LayoutSwitcher(QObject):
    def __init__(self, button: QPushButton) -> None:
        super(LayoutSwitcher, self).__init__()
        self.button = button
        self.xkb = XKeyboard()
        self.timer = QTimer(self)
        self.setup()

    def setup(self) -> None:
        self.button.clicked.connect(self.switch_and_display)
        self.timer.timeout.connect(self.display)
        self.timer.start(1000)

    def load_layouts(self) -> None:
        """Reload keyboard layouts"""
        self.xkb = XKeyboard()

    def switch_and_display(self) -> None:
        self.switch()
        self.display()

    def switch(self) -> None:
        if self.xkb.group_num >= (self.xkb.groups_count - 1):
            self.xkb.group_num = 0
        else:
            self.xkb.group_num += 1

    def display(self) -> None:
        try:
            if self.xkb.group_num >= self.xkb.groups_count:
                self.load_layouts()
                self.xkb.group_num = 0
            name = self.xkb.group_name[:2].upper()
            self.button.setText(name)
        except Exception:
            self.button.setText('EN')

    def retranslate(self) -> None:
        pass
