#!/usr/bin/env python3

import os
import sys

from PyQt5.QtWidgets import QApplication
from PyQt5.QtCore import QTranslator, QLocale

from astra_installer.settings.system_locale import Locale
from astra_installer.utils import Utils as BackendUtils
from astra_installer_qt.utils import Utils


def main() -> None:

    # Хак для обхода проблемы с системными переводами Qt
    # Запоминаем текущую локаль
    lang = BackendUtils.get_lang()
    locale = Locale.from_string(lang).language_and_territory()
    # Принудительно устанавливаем переменную окружения LANG=en_US.UTF-8 до инициализации приложения
    os.environ['LANG'] = 'en_US.UTF-8'

    app = QApplication(sys.argv)

    if not Utils.check_root_user(locale):
        return

    if not BackendUtils.check_dependencies():
        exit(1)

    try:
        BackendUtils.disable_x_screenlocker()
    except Exception as e:
        print(e)

    from astra_installer_qt.mainwindow import MainWindow

    main_window = MainWindow(locale)
    main_window.show()

    try:
        if not Utils.is_wm_present():
            screen = main_window.window().windowHandle().screen()
            rect = screen.availableGeometry()
            main_window.setGeometry(rect)
            main_window.activateWindow()

            # can't set "*:!active" because of scrollbars
            app.setStyleSheet("QMainWindow QWidget#pageSettings *:!active, "
                              "QMainWindow QFrame:!active, "
                              "QMainWindow QAbstractScrollArea:!active "
                              "{ background: palette(mid); }"
                              "QMainWindow QGroupBox QLabel:!active { background: palette(); }"
                              "QDialog { border: 1px outset palette(dark); }"
                              "QDialog QLabel:!active { background: palette(); }")
    except:
        pass

    sys.exit(app.exec_())


if __name__ == '__main__':
    main()
