from PyQt5.QtCore import QObject
from PyQt5.QtWidgets import QMainWindow, QPushButton

from astra_installer.settings.manager import SettingsManager
from astra_installer_qt.error_manager import ErrorManager


class PagesManager(QObject):
    @classmethod
    def enable_button(cls, button: QPushButton) -> None:
        button.setEnabled(True)

    @classmethod
    def disable_button(cls, button: QPushButton) -> None:
        button.setEnabled(False)

    def __init__(self, mainwindow: QMainWindow, error_manager: ErrorManager) -> None:
        super(PagesManager, self).__init__()
        self.ui = mainwindow
        self.stkw = self.ui.stackedWidgetPages
        self.error_manager = error_manager
        self.setup()

    def setup(self) -> None:
        self.ui.pushButtonBack.clicked.connect(self.open_page1)
        self.ui.pushButtonContinue.clicked.connect(self.open_page2)

    def current_page(self) -> int:
        return self.stkw.currentIndex()

    def open_page1(self) -> None:
        self.stkw.setCurrentIndex(0)

    def open_page2(self) -> None:
        self.stkw.setCurrentIndex(1)

    def open_page3(self) -> None:
        self.stkw.setCurrentIndex(2)

    def enable_continue_button(self) -> None:
        self.enable_button(self.ui.pushButtonContinue)

    def disable_continue_button(self) -> None:
        self.disable_button(self.ui.pushButtonContinue)

    def enable_install_button(self) -> None:
        if self.can_enable_install_button():
            self.enable_button(self.ui.pushButtonInstall)

    def disable_install_button(self) -> None:
        self.disable_button(self.ui.pushButtonInstall)

    def enable_finish_button(self) -> None:
        self.enable_button(self.ui.pushButtonFinish)

    def disable_finish_button(self) -> None:
        self.disable_button(self.ui.pushButtonFinish)

    def can_enable_install_button(self) -> bool:
        if SettingsManager.systeminfo.oem:
            return len(self.error_manager.errors) == 0 and \
                   SettingsManager.components.is_components_loaded and \
                   SettingsManager.security.is_components_loaded
        else:
            return len(self.error_manager.errors) == 0
