from typing import Optional

from threading import Lock

from astra_installer_kickstart.installer_storage import InstallerStorage
from astra_installer_qt.storage.blivet.installer_blivet_utils import InstallerBlivetUtils


class InstallerBlivetGUIClient:
    def __init__(self) -> None:
        self.__utils = InstallerBlivetUtils()
        self.__mutex = Lock()

    def get_storage(self) -> Optional[InstallerStorage]:
        return self.__utils.storage

    def set_storage(self, storage: Optional[InstallerStorage]) -> None:
        self.__utils.storage = storage

    def remote_call(self, method, *args):
        utils_method = getattr(self.__utils, method, None)
        if utils_method is None:
            raise RuntimeError("Unknown utils method %s" % method)

        with self.__mutex:
            return utils_method(*args)

    def remote_do_it(self, show_progress_clbk):
        return self.remote_call('blivet_do_it', show_progress_clbk)[1]
