import subprocess
import sys
import traceback

from PyQt5.QtCore import QCoreApplication
from blivetgui.communication import errors
from blivetgui.dialogs import message_dialogs, constants
from blivetgui.exception_handler import BlivetGUIExceptionHandler
from blivetgui.gui_utils import command_exists
from blivetgui.i18n import _

translate = QCoreApplication.translate

class InstallerBlivetGUIExceptionHandler(BlivetGUIExceptionHandler):
    def handle_exception(self, exc_type, exc_value, exc_traceback):

        # exceptions from blivet_utils have 'original' traceback as part of the message
        # but we want to show the original message and traceback separately
        exc_str, tr_str = self._parse_exception(exc_value)
        if tr_str is not None:
            tr_str += "------------------------------\n"
            tr_str += "".join(traceback.format_tb(exc_traceback))
        else:
            tr_str = "".join(traceback.format_tb(exc_traceback))

        allow_report = command_exists("gnome-abrt")
        allow_ignore = self.allow_ignore and not issubclass(exc_type, errors.CommunicationError)

        if allow_ignore:
            msg = _("Unknown error occured.\n{error}").format(error=exc_str)
        else:
            msg = _("Unknown error occured. Blivet-gui will be terminated.\n{error}").format(error=exc_str)

        dialog = message_dialogs.ExceptionDialog(self.main_window, allow_ignore,
                                                 allow_report, msg, tr_str)
        response = dialog.run()

        if response == constants.DialogResponseType.BACK:
            return
        else:
            # restore handler and re-raise original exception
            sys.excepthook = self.excepthook
            sys.excepthook(exc_type, exc_value, exc_traceback)

            if response == constants.DialogResponseType.REPORT:
                subprocess.call(["gnome-abrt"])

            dialog = message_dialogs.ErrorDialog(self.main_window,
                                                    translate("text", "An attempt was made to apply incorrect disk markup parameters. "
                                                        "This can lead to failures in the work of the installer and the system being installed. "
                                                        "Before proceeding, please make sure that the current markup parameters are correct."))
