from typing import TYPE_CHECKING

import gi
gi.require_version("Gtk", "3.0")

from gi.repository import Gtk

from blivetgui.dialogs.widgets import EncryptionChooser

if TYPE_CHECKING:
    from gettext import gettext as _

class InstallerBlivetEncryptionChooser(EncryptionChooser):
    def __init__(self):
        super().__init__()

        self._combobox_type.set_sensitive(False)
        self._passphrase_entry.set_icon_from_icon_name(Gtk.EntryIconPosition.SECONDARY, "dialog-error-symbolic")
        self._passphrase_entry.set_icon_tooltip_markup(Gtk.EntryIconPosition.SECONDARY, _("The passphrase is too short."))
        self._repeat_entry.set_icon_from_icon_name(Gtk.EntryIconPosition.SECONDARY, "dialog-error-symbolic")
        self._repeat_entry.set_icon_tooltip_markup(Gtk.EntryIconPosition.SECONDARY, _("The passphrase is too short."))

    def validate_user_input(self):
        selection = self.get_selection()

        if not selection.encrypt:
            return (True, None)

        if not selection.passphrase:
            msg = _("Passphrase not specified.")
            return (False, msg)
        elif len(selection.passphrase) < 8:
            msg = _("Passphrase should be at least 8 characters long.")
            return (False, msg)
        elif selection.passphrase != selection.rpassphrase:
            msg = _("Provided passphrases do not match.")
            return (False, msg)

        return (True, None)

    def _on_passphrase_changed(self, _widget):
        # check if passphrases match
        passphrase = self._passphrase_entry.get_text()

        if len(passphrase) >= 8:
            self._passphrase_entry.set_icon_from_icon_name(Gtk.EntryIconPosition.SECONDARY, "emblem-ok-symbolic")
            self._passphrase_entry.set_icon_tooltip_markup(Gtk.EntryIconPosition.SECONDARY, _("The passphrase is correct."))
        else:
            self._passphrase_entry.set_icon_from_icon_name(Gtk.EntryIconPosition.SECONDARY, "dialog-error-symbolic")
            self._passphrase_entry.set_icon_tooltip_markup(Gtk.EntryIconPosition.SECONDARY, _("The passphrase is too short."))

        if passphrase == self._repeat_entry.get_text():
            self._repeat_entry.set_icon_from_icon_name(Gtk.EntryIconPosition.SECONDARY, "emblem-ok-symbolic")
            self._repeat_entry.set_icon_tooltip_markup(Gtk.EntryIconPosition.SECONDARY, _("Passphrases match."))
        else:
            self._repeat_entry.set_icon_from_icon_name(Gtk.EntryIconPosition.SECONDARY, "dialog-error-symbolic")
            self._repeat_entry.set_icon_tooltip_markup(Gtk.EntryIconPosition.SECONDARY, _("Passphrases don't match."))
