#
#
# Copyright (C) 2014  Red Hat, Inc.
#
# This copyrighted material is made available to anyone wishing to use,
# modify, copy, or redistribute it subject to the terms and conditions of
# the GNU General Public License v.2, or (at your option) any later version.
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY expressed or implied, including the implied warranties of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the
# GNU General Public License along with this program; if not, write to the
# Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.  Any Red Hat trademarks that are incorporated in the
# source code or documentation are not subject to the GNU General Public
# License and may only be used or replicated with the express permission of
# Red Hat, Inc.
#
# Red Hat Author(s): Vojtech Trefny <vtrefny@redhat.com>
#

import gi
from PyQt5.QtCore import QCoreApplication

gi.require_version("Gtk", "3.0")
from gi.repository import Gtk

from blivetgui.list_devices import ListDevices

translate = QCoreApplication.translate


class InstallerListDevices(ListDevices):
    def __init__(self, blivet_gui):
        super().__init__(blivet_gui)
        self.disks_window = self.blivet_gui.builder.get_object("disks_window")
        self.disks_view.connect("button-release-event", self.on_right_click_event)

    def clear(self) -> None:
        self.selected_device = None
        selection = self.disks_view.get_selection()
        mode = selection.get_mode()
        selection.set_mode(Gtk.SelectionMode.NONE)
        self.device_list.clear()
        selection.set_mode(mode)

    def load_disks(self):
        """ Load disks
        """

        icon_theme = Gtk.IconTheme.get_default()  # pylint: disable=no-value-for-parameter
        icon_disk = Gtk.IconTheme.load_icon(icon_theme, "drive-harddisk", 32, 0)
        icon_disk_usb = Gtk.IconTheme.load_icon(icon_theme, "drive-removable-media", 32, 0)

        disks = self.blivet_gui.client.remote_call("get_disks")

        # hide protected and hidden disks in installer mode
        # (this will hide USB drive with installation image, disks under FW RAID etc.)
        if self.blivet_gui.installer_mode:
            for disk in disks:
                if disk.protected or disk.format.hidden:
                    disks.remove(disk)

        self.device_list.append([None, None, "<b>%s</b>" % translate('text', 'Disks')])

        for disk in disks:
            if disk.removable:
                self.device_list.append([disk, icon_disk_usb, str(disk.name + "\n<i><small>" +
                                                                  str(disk.model) + "</small></i>")])
            else:
                self.device_list.append([disk, icon_disk, str(disk.name + "\n<i><small>" +
                                                              str(disk.model) + "</small></i>")])

    def on_disk_selection_changed(self, selection):
        """ Onselect action for devices
        """

        model, treeiter = selection.get_selected()

        if treeiter and model:

            # 'Disks', 'LVM2 Volume Groups' and 'LVM2 Physical Volumes' are just
            # labels. If user select one of these, we need to unselect this and
            # select previous choice
            if not model[treeiter][0]:
                selection.handler_block(self.selection_signal)
                selection.unselect_iter(treeiter)
                selection.handler_unblock(self.selection_signal)
                if self.last_iter is not None:
                    selection.select_iter(self.last_iter)
                    treeiter = self.last_iter

            else:
                self.last_iter = treeiter

            if self.device_list.iter_is_valid(treeiter):
                self.selected_device = model[treeiter][0]
                self.blivet_gui.update_partitions_view()
                self.blivet_gui.update_physical_view()

    def on_right_click_event(self, treeview, event):
        """ Right click event on partition treeview
        """

        if event.button == 3:
            selection = treeview.get_selection()

            if selection:
                self.blivet_gui.disk_popup_menu.menu.popup_at_pointer(None)
