from PyQt5.QtCore import QObject, pyqtSignal
from PyQt5.QtWidgets import QComboBox

from astra_installer.settings.manager import SettingsManager
from astra_installer.translator import Translator


class SystemLocaleManager(QObject):
    locale_changed = pyqtSignal()

    def __init__(self, combobox: QComboBox) -> None:
        super(SystemLocaleManager, self).__init__()
        self.combobox = combobox
        self.selected_index = 0
        self.setup()

    def setup(self) -> None:
        self.add_languages()

    def add_languages(self) -> None:
        self.combobox.clear()
        self.selected_index = 0
        locale_to_select = next(iter(SettingsManager.system_locale.selected), SettingsManager.system_locale.default)
        for index, locale in enumerate(SettingsManager.system_locale.locales):
            name = Translator.locale_name(locale, SettingsManager.installer_locale.selected)
            self.combobox.addItem(name, locale)
            # TODO: хак для исправления системных переводов qt (подстановка LANG до создания QApplication) сломал
            #  загрузку системной локали (см create_system_locale_setting)
            # if SettingsManager.systeminfo.oem:
            #     if locale == locale_to_select:
            #         self.selected_index = index
            # else:
            if locale == SettingsManager.installer_locale.selected:
                self.selected_index = index
        self.combobox.setCurrentIndex(self.selected_index)

    def is_changed(self) -> bool:
        return self.selected_index != self.combobox.currentIndex()

    def apply(self) -> None:
        self.selected_index = self.combobox.currentIndex()
        selected_locale = self.combobox.currentData()
        SettingsManager.system_locale.selected = [selected_locale]
        selected_layout = SettingsManager.layout.layout_from_locale(selected_locale)
        SettingsManager.layout.selected_layouts = [selected_layout]
        SettingsManager.layout.apply()
        self.locale_changed.emit()

    def reset(self) -> None:
        self.combobox.setCurrentIndex(self.selected_index)

    def retranslate(self, locale: str) -> None:
        self.add_languages()
        self.apply()
